### About

This page demonstrates presenting several different views within a single Grid instance, by swapping out the `renderRow` function. The details and gallery views also demonstrate switching the grid header off by calling `setShowHeader`. (In fact, if only the Details and Gallery views were desired, the `List` module would be sufficient.)

In addition, the "table" view demonstrates hooking up a click callback, in order to display more information when a row is clicked.